@@ -22,7 +22,7 @@ def get_template_path(template_name):
     return os.path.join(templates_path, template_name)
     
 
-def activate_venv():
+def activate_venv(path):
 
     parent = os.getcwd()
     os.system("python -m venv env")
@@ -32,7 +32,7 @@ def activate_venv():
         env_activate_script = "Scripts"
 
     print("---path ", parent)
-    activate_file = os.path.join(parent, "env", env_activate_script, "activate")
+    activate_file = os.path.join(path, "env", env_activate_script, "activate")
     print("---activate_file ", activate_file)
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
@@ -40,9 +40,8 @@ def activate_venv():
 @app.command("")
 def main(template_name):
     template_path = get_template_path(template_name)
-    res = cookiecutter(template_path)
+    path = cookiecutter(template_path)
     project_path = os.path.join(template_path, template_name)
     print("---project_path", project_path)
-    print("--res", res)
-    activate_venv()
+    activate_venv(path)
 
